
[data-v-d037e081] .p-datatable-tbody > tr > td {
  padding: 0.25rem;
  min-height: 2rem
}
[data-v-d037e081] .p-datatable-row-selected .actions,[data-v-d037e081] .p-datatable-selectable-row:hover .actions {
  visibility: visible
}
