
.sad-container {
&[data-v-a3415c6d] {
  display: grid;
  align-items: center;
  justify-content: space-evenly;
  grid-template-columns: 25rem 1fr;
}
&[data-v-a3415c6d] > * {
    grid-row: 1;
}
}
.sad-text[data-v-a3415c6d] {
  grid-column: 1/3;
}
.sad-girl[data-v-a3415c6d] {
  grid-column: 2/3;
  width: min(75vw, 100vh);
}
