
.p-tag[data-v-b6ad21dc] {
  --p-tag-gap: 0.5rem;
}
.hover-brighten {
&[data-v-b6ad21dc] {
  transition-property: color, background-color, border-color, text-decoration-color, fill, stroke;
  transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);
  transition-duration: 150ms;
  transition-property: filter, box-shadow;
  }
&[data-v-b6ad21dc]:hover {
    filter: brightness(107%) contrast(105%);
    box-shadow: 0 0 0.25rem #ffffff79;
}
}
.p-accordioncontent-content[data-v-b6ad21dc] {
  border-radius: 0.5rem;
  --tw-bg-opacity: 1;
  background-color: rgb(23 23 23 / var(--tw-bg-opacity));
  transition-property: color, background-color, border-color, text-decoration-color, fill, stroke;
  transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);
  transition-duration: 150ms;
}
div.selected {
.gpu-button[data-v-b6ad21dc]:not(.selected) {
    opacity: 0.5;
}
.gpu-button[data-v-b6ad21dc]:not(.selected):hover {
    opacity: 1;
}
}
.gpu-button[data-v-b6ad21dc] {
  margin: 0px;
  display: flex;
  width: 50%;
  cursor: pointer;
  flex-direction: column;
  align-items: center;
  justify-content: space-around;
  border-radius: 0.5rem;
  background-color: rgb(38 38 38 / var(--tw-bg-opacity));
  --tw-bg-opacity: 0.5;
  transition-property: color, background-color, border-color, text-decoration-color, fill, stroke;
  transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);
  transition-duration: 150ms;
}
.gpu-button[data-v-b6ad21dc]:hover {
  --tw-bg-opacity: 0.75;
}
.gpu-button {
&.selected[data-v-b6ad21dc] {
    --tw-bg-opacity: 1;
    background-color: rgb(64 64 64 / var(--tw-bg-opacity));
}
&.selected[data-v-b6ad21dc] {
    --tw-bg-opacity: 0.5;
}
&.selected[data-v-b6ad21dc] {
    opacity: 1;
}
&.selected[data-v-b6ad21dc]:hover {
    --tw-bg-opacity: 0.6;
}
}
.disabled[data-v-b6ad21dc] {
  pointer-events: none;
  opacity: 0.4;
}
.p-card-header[data-v-b6ad21dc] {
  flex-grow: 1;
  text-align: center;
}
.p-card-body[data-v-b6ad21dc] {
  padding-top: 0px;
  text-align: center;
}

[data-v-575095bc] .p-steppanel {
    background-color: transparent
}
